/*
 * Copyright (C) 2002 Thomas Hacklaender, mailto:hacklaender@iftm.de
 *
 * IFTM Institut fuer Telematik in der Medizin GmbH, www.iftm.de
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU  General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * http://www.gnu.org/copyleft/copyleft.html
 */
package de.iftm.dcm4che.dcmie.inspect;

import java.io.*;
import javax.swing.*;

import org.dcm4che.Implementation;

import de.iftm.javax.swing.filetree.*;
import de.iftm.java.util.*;
import de.iftm.dcm4che.image.*;
import de.iftm.dcm4che.dcmie.*;


/**
 * @author   Thomas Hacklaender
 * @version  2002.8.22
 */
public class DcmInspectorPanel extends javax.swing.JPanel implements java.io.Serializable {

  
	/**
	 * Version number of this plugin
	 */
	public final static String    VERSION = "1.0.0";
 
  
  /**
   * Creates new form DirPanel
   */
  public DcmInspectorPanel() {
    initComponents();
    myInitComponents();
  }
  
  
  /**
   * Set up the Panel
   */
  public void setUp(DcmieParam dcmieParam) {
    // SelInputPanel Tabs initialisieren und als fileSelectionListener registrieren
    selInputPanel.setUp(dcmieParam);
    selInputPanel.getFileSystemTab().getTreePanel().addFileSelectionListener(selInputPanel);
    selInputPanel.getDICOMDIRTab().getDirTable().addFileSelectionListener(selInputPanel);

    // ImagePanel Tabs initialisieren und als fileSelectionListener registrieren
    imagePanel.setUp(dcmieParam);
    selInputPanel.getFileSystemTab().getTreePanel().addFileSelectionListener(imagePanel);
    selInputPanel.getDICOMDIRTab().getDirTable().addFileSelectionListener(imagePanel);

    // TablePanel Tabs initialisieren und als fileSelectionListener registrieren
    tablePanel.setUp(dcmieParam);
    selInputPanel.getFileSystemTab().getTreePanel().addFileSelectionListener(tablePanel);
    selInputPanel.getDICOMDIRTab().getDirTable().addFileSelectionListener(tablePanel);

    // XMLPanel Tabs initialisieren und als fileSelectionListener registrieren
    xmlPanel.setUp(dcmieParam);
    selInputPanel.getFileSystemTab().getTreePanel().addFileSelectionListener(xmlPanel);
    selInputPanel.getDICOMDIRTab().getDirTable().addFileSelectionListener(xmlPanel);
  }

  
  /** This method is called from within the constructor to
   * initialize the form.
   */
  private void myInitComponents() {
    thisCopyright.setText("(c) 2002 by Thomas Hacklaender under the GNU General Public License. Version: " + VERSION);
    dcmCopyright.setText("Based on the DICOM library http://sourceforge.net/projects/dcm4che/ by Gunter Zeilinger. Version: " + Implementation.getVersionName());
  }

  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    java.awt.GridBagConstraints gridBagConstraints;

    thisCopyright = new javax.swing.JLabel();
    dcmCopyright = new javax.swing.JLabel();
    mainTabPane = new javax.swing.JTabbedPane();
    selInputPanel = new de.iftm.dcm4che.dcmie.inspect.SelInputPanel();
    imagePanel = new de.iftm.dcm4che.dcmie.inspect.ImagePanel();
    tablePanel = new de.iftm.dcm4che.dcmie.inspect.TablePanel();
    xmlPanel = new de.iftm.dcm4che.dcmie.inspect.XMLPanel();

    setLayout(new java.awt.GridBagLayout());

    setMinimumSize(new java.awt.Dimension(256, 128));
    setPreferredSize(new java.awt.Dimension(0, 0));
    thisCopyright.setFont(new java.awt.Font("Dialog", 0, 10));
    thisCopyright.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
    thisCopyright.setText(" ");
    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 0;
    gridBagConstraints.gridy = 1;
    gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
    gridBagConstraints.insets = new java.awt.Insets(10, 5, 0, 10);
    add(thisCopyright, gridBagConstraints);

    dcmCopyright.setFont(new java.awt.Font("Dialog", 0, 10));
    dcmCopyright.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
    dcmCopyright.setText(" ");
    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 0;
    gridBagConstraints.gridy = 2;
    gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
    gridBagConstraints.insets = new java.awt.Insets(0, 5, 10, 10);
    add(dcmCopyright, gridBagConstraints);

    mainTabPane.addTab("Select File", null, selInputPanel, "null");

    mainTabPane.addTab("Image View", null, imagePanel, "null");

    mainTabPane.addTab("Table View", null, tablePanel, "null");

    mainTabPane.addTab("XML View", xmlPanel);

    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.weighty = 1.0;
    add(mainTabPane, gridBagConstraints);

  }//GEN-END:initComponents
  
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private de.iftm.dcm4che.dcmie.inspect.XMLPanel xmlPanel;
  private de.iftm.dcm4che.dcmie.inspect.ImagePanel imagePanel;
  private javax.swing.JTabbedPane mainTabPane;
  private javax.swing.JLabel dcmCopyright;
  private de.iftm.dcm4che.dcmie.inspect.TablePanel tablePanel;
  private de.iftm.dcm4che.dcmie.inspect.SelInputPanel selInputPanel;
  private javax.swing.JLabel thisCopyright;
  // End of variables declaration//GEN-END:variables
  
}
