/*
 * Copyright (C) 2002 Thomas Hacklaender, mailto:hacklaender@iftm.de
 *
 * IFTM Institut fuer Telematik in der Medizin GmbH, www.iftm.de
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU  General Public License as published by the 
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * http://www.gnu.org/copyleft/copyleft.html
 */
package de.iftm.dcm4che.dcmie.inspect;

import java.awt.*;
import java.io.*;

import javax.swing.*;
import javax.swing.tree.*;

import de.iftm.dcm4che.image.*;
import de.iftm.dcm4che.dcmie.*;
import de.iftm.javax.swing.filetree.*;
import de.iftm.java.util.*;


/**
 * @author   Thomas Hacklaender
 * @version  2002.06.23
 */
public class SelInputPanel extends javax.swing.JPanel implements FileSelectionListener, java.io.Serializable {
  
  // The last selected roor directory
  private File    lastRootDir = null;
  
  /**
   * Creates new form DirPanel
   */
  public SelInputPanel() {
    initComponents();
  }
  
  
  /**
   * Set up the Panel
   */
  public void setUp(DcmieParam dcmieParam) {
    
    // Default Setup
    fileInfoPanel.setUp(dcmieParam);
    
    // Default Setup
    fileSystemTab.setUp(dcmieParam);
    // Es darf immer nur ein File ausgewaehlt werden
    fileSystemTab.getTreePanel().getTree().getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);

    // Default Setup
    dcmDirTab.setUp(dcmieParam);
    // Auch bei Serie und Image darf jeweil nur ein Eintrag ausgewaehlt werde
    dcmDirTab.getDirTable().getSeriesTable().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    dcmDirTab.getDirTable().getImageTable().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    
    if (dcmieParam.isImportFilesystem) {
      selectTabComponent(getFileSystemTab());
    } else {
      selectTabComponent(getDICOMDIRTab());
    }
  }
  

  /**
   * Implementation of the FileSelectionListener interface.
   * @param e the FileSelection event.
   */
  public void fileSelected(FileSelectionEvent e) {
    
    // Info anzeigen
    fileInfoPanel.setInput(e.getLastSelectedFile());
    
    // BIld datstellen
    try {
      imageBean.setSizePolicy(ImageBean.SIZE_POLICY_FIT);
      imageBean.setInput(e.getLastSelectedFile());
    } catch (Exception ex) {
      // Default Bild darstellen
      try {
        imageBean.setInput((File) null);
      } catch (Exception ex2) {}
    }
  }

  
  /**
   * Returns the FileSystemPanel.
   * @return the FileSystemPanel.
   */
  public FileSystemTab getFileSystemTab() {
    return fileSystemTab;
  }
  
  
  /**
   * Returns the DcmDirPanel.
   * @return the DcmDirPanel.
   */
  public DcmDirTab getDICOMDIRTab() {
    return dcmDirTab;
  }
  
  
  /**
   * Select a tab.
   * @param comp the selected tab.
   */
  public void selectTabComponent(Component comp) {
    if (comp == fileSystemTab) {
      tabbedPane.setSelectedComponent(fileSystemTab);
    }
    
    if (comp == dcmDirTab) {
      tabbedPane.setSelectedComponent(dcmDirTab);
    }
    
    // Ungueltige Component, nichts tun
  }

  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    java.awt.GridBagConstraints gridBagConstraints;

    tabbedPane = new javax.swing.JTabbedPane();
    fileSystemTab = new de.iftm.dcm4che.dcmie.inspect.FileSystemTab();
    dcmDirTab = new de.iftm.dcm4che.dcmie.inspect.DcmDirTab();
    imageBean = new de.iftm.dcm4che.image.ImageBean();
    fileInfoPanel = new de.iftm.dcm4che.dcmie.inspect.FileInfoPanel();

    setLayout(new java.awt.GridBagLayout());

    setMinimumSize(new java.awt.Dimension(256, 64));
    setPreferredSize(new java.awt.Dimension(0, 0));
    tabbedPane.addTab("Filesystem", null, fileSystemTab, "null");

    tabbedPane.addTab("DICOMDIR", dcmDirTab);

    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 1;
    gridBagConstraints.gridy = 0;
    gridBagConstraints.gridheight = 2;
    gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.weighty = 1.0;
    gridBagConstraints.insets = new java.awt.Insets(5, 20, 5, 5);
    add(tabbedPane, gridBagConstraints);

    imageBean.setMaximumSize(new java.awt.Dimension(192, 192));
    imageBean.setMinimumSize(new java.awt.Dimension(192, 192));
    imageBean.setPreferredSize(new java.awt.Dimension(192, 192));
    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 0;
    gridBagConstraints.gridy = 0;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.weighty = 1.0;
    gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 0);
    add(imageBean, gridBagConstraints);

    fileInfoPanel.setPreferredSize(new java.awt.Dimension(256, 128));
    gridBagConstraints = new java.awt.GridBagConstraints();
    gridBagConstraints.gridx = 0;
    gridBagConstraints.gridy = 1;
    gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints.weightx = 1.0;
    gridBagConstraints.weighty = 1.0;
    gridBagConstraints.insets = new java.awt.Insets(0, 5, 9, 0);
    add(fileInfoPanel, gridBagConstraints);

  }//GEN-END:initComponents
  

  // Variables declaration - do not modify//GEN-BEGIN:variables
  private de.iftm.dcm4che.dcmie.inspect.DcmDirTab dcmDirTab;
  private de.iftm.dcm4che.image.ImageBean imageBean;
  private de.iftm.dcm4che.dcmie.inspect.FileInfoPanel fileInfoPanel;
  private javax.swing.JTabbedPane tabbedPane;
  private de.iftm.dcm4che.dcmie.inspect.FileSystemTab fileSystemTab;
  // End of variables declaration//GEN-END:variables
  
}
